@@ -1,4 +1,4 @@
-__all__ = ('validate_data',)
+__all__ = ('validate_data', 'parse_for_mongo_query', 'parse_for_django_query')
 
 
 class __Validate(object):
@@ -52,9 +52,9 @@ class __Validate(object):
                 query_dict = {} if mongo else {'filter': {}, 'exclude': {}}
                 for p in parsed:
                     if mongo:
-                        query_dict.update()
+                        query_dict.update(self.generate_mongo_query(p))
                     else:
-                        f, ex = self.generate_mongo_query(p)
+                        f, ex = self.generate_django_orm_query(p)
                         query_dict['filter'].update(f)
                         query_dict['exclude'].update(ex)
                 queries.append(query_dict)
